table_ident_from_object_name

Function table_ident_from_object_name 

fn table_ident_from_object_name(
    name: &ObjectName,
    current_schema: &str,
) -> Result<MySqlTableName, TransientError>
This function has the same intent as table_ident except handles the object name type parsed out of the sql by sqlparser rather than a raw string. The ObjectName type is more flexible than the constraints for an identifier in mysql. i.e. it has a function type, which appears to only be supported in snowflake. It also has a vector for identifier components, however a table identifier from the binlog should only have 1 or 2 components - never 0 or more than 2